use "MIA export jul 12.dta", clear

*install additional Stata packages used in the analysis

ssc install cibar
ssc install outreg2
ssc install ivreg2 
ssc install xtivreg2
ssc install xtoverid
ssc install ranktest 
ssc install xtseqreg


order init end, after (creation)
/*init=first year in dataset || end=last year in dataset*/
tsset ionumber year


gen inception_adj=creation
replace inception_adj=1950 if creation<1950
gen age_adj=year-inception_adj+1 
// rationale is that even for older IOs, WWII reset the clock pretty much for discovering cooperation

*Convert contract variable into 0 1
gen contract1=1 if contract==2
replace contract1=0 if contract==1

/*We measure Members as the natural log of the absolute number of member states in a given year on the assumption that the effect of an additional member declines as the absolute number increases */

gen membersln=ln(members)

*add labels to key variables
label variable age_adj "Age"
label variable contract "Incomplete contract"
label variable scope "Policy scope"
label variable membersln "Members ln"
label variable democracy "Democracy"
label variable cincmod "Power asymmetry"
label variable year "Year"
label variable tradeintro "Trade introversion"
label variable tradeintensity "Trade intensity"
label variable UNvote "idealpoints Voeten measure (standard deviation)"
label define contraact 0 "Closed-ended contract" 1 "Open-ended contract"
label values initcontract contraact
label variable politmovinglog10new "Politicization"

*Figure 1. Temporal evolution of average delegation in a continuous sample from 1975 to 2019 and the full sample. 

*identify first and last occurence in a panel

by ioname, sort: egen firsttime = min(cond(delegation !=., year, .))
by ioname: egen lasttime = max(cond(delegation !=., year, .))

*generate average delegation score for the IOs in existence 1975-2019; the year>=1975 makes the line begin at 1975
bysort year: egen average_delegation_subset=mean(delegation) if firsttime<=1975& lasttime==2019&year>=1975 
bysort year: egen average_delegation=mean(delegation) 

twoway (line average_delegation year) (line average_delegation_subset year),  xlabel(1950(10)2020)

*Figure 2. Change in delegation in 41 regional IOs, 1950-2019

preserve
keep ioname id ionumber year delegation

sort id year

bysort id : keep if _n==1 | _n==_N

bysort id : gen exp1=delegation if _n==1
bysort id : replace exp1=exp1[_n-1] if exp1==.

bysort id : gen exp2=delegation if _n==_N
bysort id : replace exp2=exp2[_n+1] if exp2==.

gen exp3=exp2-exp1
gen exp4=0

bysort id: keep if _n==_N
sort exp3 id
replace id=_n

#delimit ; 
label define id 1 "CERN" 2 "ECCAS" 3 "NAFTA" 4 "SAARC" 5 "SELA" 6 "CCNR" 7 "EEA" 8 "ESA"
9 "GCC" 10 "COMECON" 11 "SPC" 12 "APEC" 13 "Nordic" 14 "IGAD" 15 "SACU" 16 "ALADI" 
17 "OAS" 18 "EFTA" 19 "SCO" 20 "EU" 21 "CAN" 22 "COMESA" 23 "OAPEC" 24 "Caricom"
25 "OSCE" 26 "EAC1" 27 "AMU" 28 "OECS" 29 "ASEAN" 30 "CIS" 31 "AU" 32 "PIF" 33 "SADC"
34 "LOAS" 35 "Benelux" 36 "Mercosur" 37 "SICA" 38 "COE" 39 "CEMAC" 40 "EAC2" 41 "ECOWAS"
; #delimit cr

label values id id

#delimit ; 
graph twoway
	rbar exp4 exp3 id, hor fc("120 120 120") lc(black) barw(0.15)
	|| rscatter exp4 exp4 id, hor m(0) mc("240 0 0") msize(*1)
	|| rscatter exp3 exp3 id, hor m(0) mc("0 0 240") msize(*1)
	||, ylabel(1(1)41, angle(horizontal) valuelabel nogrid labsize(*0.75)) ytitle("")
	xtitle("Change in delegation", c(black) size(small) margin(0 0 0 2))
	xlabel(-0.1(0.1)0.7, grid glw(vthin) glc("120 120 120") labsize(small)) xmtick(##4)
	legend( ring(0) col(1) order(2 "At creation" 3 "In 2019 or at dissolution") 
	 colgap(*2.5) s(*0.75) region(style(none)))	
	xsize(5) ysize(5) scale(0.7)
	graphregion(margin(l=3 r=6 b=3 t=6)) graphregion(color(white) lwidth(vthick)) plotregion(icolor(white) m(zero))
; #delimit cr
graph export delegation_sorted2.png, replace width(1000) height(1000)

restore

*Figure 4. Mean change in policy scope and delegation based on type of contract

*Figure 4a - Policy scope change

by ioname, sort: egen first_policy = min(cond(scope !=., year, .))
by ioname, sort: egen last_policy = max(cond(scope !=., year, .))

*Generate a variable for policy change (last policy score-first policy score)
 by ioname, sort: gen scope_first = scope if year==first_policy
 by ioname, sort: gen scope_last = scope if year==last_policy

 *Replace missing values in a cascading manner
 tsset ionumber year 
 replace scope_first = L.scope_first if scope_first >= . 
		
 *Replace missing values in a cascading manner, but now with years in descending order
		
gsort ionumber -year 
quietly by ionumber: replace scope_last = scope_last[_n-1] if scope_last >= . 
sort ionumber year 

*generate the scope change variable
by ioname, sort: gen scope_change=scope_last-scope_first

*bar graph with 95 CI
cibar scope_change, over(initcontract) level(95) barlabel(on) ///
 graphopts(ytitle(Mean policy scope) title(Mean policy scope change based on type of contract with 95% CIs) subtitle(Year of founding - 2019)) bargap(50)
 

*Figure 4b - same as Figure 4a above but now for delegation 

*Generate the years of first and last occurence of delegation in the data
 by ioname, sort: egen first_delegation = min(cond(delegation !=., year, .))
by ioname, sort: egen last_delegation = max(cond(delegation !=., year, .))

*Generate a variable for policy change (last policy score-first policy score)
 by ioname, sort: gen delegation_first = delegation if year==first_delegation
 by ioname, sort: gen delegation_last = delegation if year==last_delegation

 *Replace missing values in a cascading manner
 tsset ionumber year 
 replace delegation_first = L.delegation_first if delegation_first >= . 
		
 *Replace missing values in a cascading manner, but now with years in descending order
		
gsort ionumber -year 
quietly by ionumber: replace delegation_last = delegation_last[_n-1] if delegation_last >= . 
sort ionumber year 

*generate the delegation change variable
by ioname, sort: gen delegation_change=delegation_last-delegation_first

 cibar delegation_change, over(initcontract) level(95) barlabel(on) ///
 graphopts(ytitle(Mean delegation score) title(Mean delegation score change based on type of contract with 95% CIs) subtitle(Year of founding - 2019)) bargap(10)


//**EXPLAINING SCOPE 

tsset ionumber year

*Rescale cgdp cgdpsd by standardizing them for easier interpretation 

egen cgdp_s=std(cgdp)
egen cgdpsd_s=std(cgdpsd)


*Table 2 (policy), model 1 - baseline

xtreg f.scope i.contract1##c.age_adj , fe vce (cl ionumber)
  outreg2 using contract, dec(3) word replace label

*Table 2 (policy), model 2 - extended baseline model

xtreg f.scope i.contract1##c.age_adj cincmod intratrade  UNvote, fe vce (cl ionumber)
  outreg2 using contract, dec(3) word  label

*Table 2 (policy), model 3
*model with % of intra-IO trade

xtreg f.scope i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote, fe vce (cl ionumber)
  outreg2 using contract, dec(3) word  label

  margins, at (age_adj=(0 (5) 70) contract1=(0 1)) atmeans
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) scheme(lean1)  

*Table 2 (policy), model 4

*model with trade intensity 
xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod tradeintensity coldwar UNvote, fe vce (cl ionumber)

  outreg2 using contract, dec(3) word  label
  
*Table 2 (policy), model 5

  *model with  trade introversion  
xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod tradeintro coldwar UNvote, fe vce (cl ionumber)

  outreg2 using contract, dec(3) word  label
  
*Table 2 (policy), model 6

*model with CINC measure for assymetry (unmodified)
xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cinc intratrade coldwar UNvote, fe vce (cl ionumber)

  outreg2 using contract, dec(3) word  label
  

*Table 2 (policy), model 7

*model  excluding the 3 IOs that have a contract change (Benelux, CARICOM, IGAD)
xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote if ioname!="Benelux"&ioname!="Caricom"&ioname!="IGAD", fe vce (cl ionumber)
  
  outreg2 using contract, dec(3) word  label

*hausman tests suggests fixed effects are appropriate
 xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote, fe 
 est store fixed
 
  xtreg f.scope  i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote, re 
 hausman fixed 


*EXPLAINING DELEGATION
*Table 3


*Three-way interaction for democratic and autocratic IOs
*create a split sample in IOs with low and high democracy
gen demdich=1 if democracy>.5
replace demdich=0 if democracy<.5
label define demdich 0 "autocratic" 1 "democratic"
label values demdich demdich


 *Table 3 (delegation), model 1 - baseline
 
xtreg f.delegation scope, fe vce (cl ionumber)

outreg2 using delegation, dec(3) word replace label


 *Table 3 (delegation), model 2 - extended baseline

xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich, fe vce (cl ionumber)

outreg2 using delegation, dec(3) word label


 *Table 3 (delegation), model 3 - main model

xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe vce (cl ionumber)

outreg2 using delegation, dec(3) word label

margins, dydx(scope) at(politmovinglog10new=(0(0.5) 3.185777) demdich=(0 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash))  yline(0) scheme(lean1) saving(dem_test.gph, replace) 


margins, dydx(scope) at(politmovinglog10new=(0(0.5) 3.185777) demdich=(1 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) saving(dem_test1.gph, replace) 

graph combine dem_test.gph dem_test1.gph,  rows (1)  // USE THIS for FIGURE POLITICIZATION


  
 *Table 3 (delegation), model 4 

*model with trade intensity 

xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year tradeintensity coldwar UNvote , fe vce (cl ionumber)

outreg2 using delegation, dec(3) word  label

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=(0 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=( 1))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

 
 *Table 3 (delegation), model 5

  *model with  trade introversion  
  
  xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year tradeintro coldwar UNvote , fe vce (cl ionumber)

outreg2 using delegation, dec(3) word  label

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=(0 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=( 1))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

  
 *Table 3 (delegation), model 6

*model CINC measure for assymetry (unmodified)
xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cinc cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe vce (cl ionumber)

outreg2 using delegation, dec(3) word  label

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=(0 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=( 1))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 


   *Table 3 (delegation), model 7

*model excluding the 3 IOs that have a contract change (Benelux, CARICOM, IGAD)

xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote if ioname!="Benelux"&ioname!="Caricom"&ioname!="IGAD", fe vce (cl ionumber)

outreg2 using delegation, dec(3) word  label

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=(0 ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 

margins, dydx(politmovinglog10new) at(scope=(0(5)25) demdich=( 1))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) 


  *Hausman test to decide whether to use FE or RE

xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe 

 est store fixed
 
xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , re

 hausman fixed 

*We reject the null hypothesis, so the Hausman test suggests that we should use fixed effects

										****ROBUSTNESS CHECKS****

 *Granger causality test for panel data
 
 * delete IOs which have little change in delegation or scope because Granger tests dont work with such IOs in the sample

 *First, preserve the dataset so it can be restored later with all IOs
preserve

drop if ionumber==1230|ionumber==1050|ionumber==1370|ionumber==1720|ionumber==1750|ionumber==1790|ionumber==1831| ///
ionumber==3390|ionumber==3670|ionumber==4170|ionumber==4240|ionumber==5550

*No missing values are allowed

drop if scope==.|delegation==.
xtset ionumber year

*Run the Granger causality test with two lags
xtgcause scope delegation , l(2) regress   

*Restore dataset so all IOs are included
restore


*IOs with recursivity - 4200 (PIF), 4190 (SPC), 1990 (GCC), 1500 (ECCAS)   


* In sum, we can reject H0 that scope does not Granger-cause delegation. Scope does Granger-cause delegation for at least 4 IOs (PIF, SPC, GCC, and ECCAS)


 
 *************************************
 ** TWO-STAGE MODEL fOR POLICY SCOPE
 *************************************

 *Appendix, Table E1 - Two-stage fixed effects OLS regression

gen yearcc=year // we cannot use the same variable (year) as time set variable hence rename


*calculate historical ties -- use the most conservative estimate of historical ties, not including ties for EU, LOAS, AU
/*(a) create a variable that indicate the last year of historical ties (federation or colonial empire) -- see also INDEP_dataset of book*/
gen ties_end=1905 if ioname=="Nordic"
replace ties_end=1922 if ioname=="SICA"
replace ties_end=1945 if ioname=="LOAS"
replace ties_end=1948 if ioname=="Benelux"
replace ties_end=1951 if ioname=="OAS"
replace ties_end=1952 if ioname=="EU"
replace ties_end=1958 if ioname=="CEMAC"
replace ties_end=1960 if ioname=="COMESA"| ioname =="IGAD" | ioname=="AMU"
replace ties_end=1961 if ioname=="EAC1"| ioname=="EAC2"
replace ties_end=1962 if ioname=="Caricom"| ioname=="OECS"
replace ties_end=1963 if ioname=="AU"
replace ties_end=1965 if ioname=="PIF"
replace ties_end=1971 if ioname=="GCC"
replace ties_end=1991 if ioname=="CIS"
replace ties_end=0 if ties_end==.
tab ties_end, missing


/*(b) calculate historydynamic by adding a decay factor that reflects the temporal distance between end of historical ties and start of IO*/

gen historydynamic4=exp(-(inception-ties_end)/25) if historical_ties4==1
replace historydynamic4=0 if historical_ties4==0
replace historydynamic4=historydynamic4*age_adj
tab historydynamic4
label variable historydynamic4 "historical ties4 * decay factor * with age of IO"
order ties_end historydynamic4, after (historical_ties4)

gen contractdynamic=contract*age_adj

xtivreg2 f.scope membersln democracy cincmod cgdp_s cgdpsd_s intratrade UNvote yearcc (contractdynamic=historydynamic4), fe first r cl(ionumber) // this is the first + second stage
/*focus on Kleibergen and Stock-Yogo statistics to evaluate strength of instrument and exogeneity -- see explanation via ivreg2*/

xtreg f.contractdynamic membersln democracy cincmod cgdp_s cgdpsd_s intratrade coldwar yearcc historydynamic4, fe vce (cl ionumber) // to calculate the overall R2 of the first stage

 
* Appendix F- additional robustness checks

*Table F1-policy scope
*model 1 with random effects
xtreg f.scope i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote, re vce (cl ionumber)

outreg2 using appendix_contract, dec(3) word replace label

  
*model 2 with lagged dependent variable
xtreg f.scope scope i.contract1##c.age_adj membersln democracy cgdp_s cgdpsd_s cincmod intratrade coldwar UNvote, fe vce (cl ionumber)

outreg2 using appendix_contract, dec(3) word label

*Table F2-delegation

*model 1 with random effects
xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , re vce (cl ionumber)

  outreg2 using appendix_delegation, dec(3) word  label replace
  
  *model 2 with lagged dependent variable  
xtreg f.delegation delegation c.scope##c.politmovinglog10new##i.demdich membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe vce (cl ionumber)

  outreg2 using appendix_delegation, dec(3) word  label
  
    *model 3 with lagged dependent variable but without three-way interaction
xtreg f.delegation delegation scope membersln democracy cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe vce (cl ionumber)

  outreg2 using appendix_delegation, dec(3) word  label
  
  *model 4 with continuous V-Dem measure of democracy

/* determined high and low values for democracy variable */

sum democracy
global democracy_high=r(mean)+r(sd)
global democracy_low=r(mean)-r(sd)

xtreg f.delegation c.scope##c.politmovinglog10new##c.democracy membersln  cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote , fe vce (cl ionumber)

  outreg2 using appendix_delegation, dec(3) word  label

margins, dydx(scope) at(politmovinglog10new=(0(0.5) 3.185777) democracy=($democracy_low ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) saving(democracy_test.gph, replace) 

margins, dydx(scope) at(politmovinglog10new=(0 (0.5) 3.185777) democracy=($democracy_high ))  vsquish 
marginsplot, recastci(rline) ciopts(lpattern(shortdash)) yline(0) scheme(lean1) saving(democracy1_test.gph, replace) 

*Appendix F, Figure F1
graph combine democracy_test.gph democracy1_test.gph,  rows (1)  

** Model 5 - exluding 4 IOS with recursive relationship between policy expansion and delegation 
**4200 (PIF), 4190 (SPC), 1990 (GCC), 1500 (ECCAS) 


xtreg f.delegation c.scope##c.politmovinglog10new##i.demdich membersln cincmod cgdp_s cgdpsd_s  year intratrade coldwar UNvote if ionumber!=4200&ionumber!=4190&ionumber!=1990&ionumber!=1500, fe vce (cl ionumber)

  outreg2 using appendix_delegation, dec(3) word  label

**ADDITIONAL ANALYSES MENTIONED IN THE MANUSCRIPT

*Cross-sectional analysis of scope and delegation, with mean values for IVs (see footnote 9)

 *First, preserve the dataset so it can be restored later with full dataset
preserve

*calculate means for covariates
 by ioname, sort: egen scope_mean=mean(scope) 
by ioname, sort: egen membersln_mean=mean(membersln) 
 by ioname, sort: egen democracy_mean=mean(democracy) 
  by ioname, sort: egen cgdp_mean=mean(cgdp) 
  by ioname, sort: egen cgdpsd_mean=mean(cgdpsd) 
  by ioname, sort: egen cincmod_mean=mean(cincmod) 
  by ioname, sort: egen intratrade_mean=mean(intratrade) 
    by ioname, sort: egen UNvote_mean=mean(UNvote) 

*drop duplicate observations to run cross-sectional analysis  
by scope_mean, sort:  gen dup = cond(_N==1,0,_n)
drop if dup>1
   

 reg scope_change  contract membersln_mean democracy_mean cgdp_mean ///
 cgdpsd_mean cincmod_mean intratrade_mean UNvote_mean

restore

preserve

*calculate means for covariates
 by ioname, sort: egen delegation_mean=mean(delegation) 
by ioname, sort: egen membersln_mean=mean(membersln) 
 by ioname, sort: egen democracy_mean=mean(democracy) 
  by ioname, sort: egen cgdp_mean=mean(cgdp) 
  by ioname, sort: egen cgdpsd_mean=mean(cgdpsd) 
  by ioname, sort: egen cincmod_mean=mean(cincmod) 
  by ioname, sort: egen intratrade_mean=mean(intratrade) 
  by ioname, sort: egen politmoving300new_mean=mean(politmoving300new)
      by ioname, sort: egen UNvote_mean=mean(UNvote) 

  
*drop duplicate observations to run cross-sectional analysis  
by delegation_mean, sort:  gen dup = cond(_N==1,0,_n)
drop if dup>1
   
 reg delegation_change  contract membersln_mean democracy_mean cgdp_mean ///
 cgdpsd_mean cincmod_mean intratrade_mean UNvote_mean
 
 restore
